PRISM Documentation
=================================
.. image:: _images/logo_bgwhite.png
    :align: center

Methylation **P**\attern-based, **R**\eference-free **I**\nference of **S**\ubclonal **M**\akeup

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   source/prism

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
